@@ -25,6 +25,8 @@ from .literals import (
     ConditionalOperatorType,
     ContributorInsightsActionType,
     ExportFormatType,
+    InputCompressionTypeType,
+    InputFormatType,
     ReturnConsumedCapacityType,
     ReturnItemCollectionMetricsType,
     ReturnValueType,
@@ -62,6 +64,7 @@ from .type_defs import (
     DescribeExportOutputTypeDef,
     DescribeGlobalTableOutputTypeDef,
     DescribeGlobalTableSettingsOutputTypeDef,
+    DescribeImportOutputTypeDef,
     DescribeKinesisStreamingDestinationOutputTypeDef,
     DescribeLimitsOutputTypeDef,
     DescribeTableOutputTypeDef,
@@ -77,6 +80,8 @@ from .type_defs import (
     GlobalSecondaryIndexTypeDef,
     GlobalSecondaryIndexUpdateTypeDef,
     GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef,
+    ImportTableOutputTypeDef,
+    InputFormatOptionsTypeDef,
     KeysAndAttributesTypeDef,
     KeySchemaElementTypeDef,
     KinesisStreamingDestinationOutputTypeDef,
@@ -84,6 +89,7 @@ from .type_defs import (
     ListContributorInsightsOutputTypeDef,
     ListExportsOutputTypeDef,
     ListGlobalTablesOutputTypeDef,
+    ListImportsOutputTypeDef,
     ListTablesOutputTypeDef,
     ListTagsOfResourceOutputTypeDef,
     LocalSecondaryIndexTypeDef,
@@ -99,9 +105,11 @@ from .type_defs import (
     ReplicaUpdateTypeDef,
     RestoreTableFromBackupOutputTypeDef,
     RestoreTableToPointInTimeOutputTypeDef,
+    S3BucketSourceTypeDef,
     ScanOutputTypeDef,
     SSESpecificationTypeDef,
     StreamSpecificationTypeDef,
+    TableCreationParametersTypeDef,
     TagTypeDef,
     TimeToLiveSpecificationTypeDef,
     TransactGetItemsOutputTypeDef,
@@ -149,6 +157,8 @@ class Exceptions:
     GlobalTableAlreadyExistsException: Type[BotocoreClientError]
     GlobalTableNotFoundException: Type[BotocoreClientError]
     IdempotentParameterMismatchException: Type[BotocoreClientError]
+    ImportConflictException: Type[BotocoreClientError]
+    ImportNotFoundException: Type[BotocoreClientError]
     IndexNotFoundException: Type[BotocoreClientError]
     InternalServerError: Type[BotocoreClientError]
     InvalidExportTimeException: Type[BotocoreClientError]
@@ -387,6 +397,14 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_global_table_settings)
         """
 
+    def describe_import(self, *, ImportArn: str) -> DescribeImportOutputTypeDef:
+        """
+        Represents the properties of the import.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.describe_import)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#describe_import)
+        """
+
     def describe_kinesis_streaming_destination(
         self, *, TableName: str
     ) -> DescribeKinesisStreamingDestinationOutputTypeDef:
@@ -541,6 +559,23 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#get_item)
         """
 
+    def import_table(
+        self,
+        *,
+        S3BucketSource: S3BucketSourceTypeDef,
+        InputFormat: InputFormatType,
+        TableCreationParameters: TableCreationParametersTypeDef,
+        ClientToken: str = ...,
+        InputFormatOptions: InputFormatOptionsTypeDef = ...,
+        InputCompressionType: InputCompressionTypeType = ...
+    ) -> ImportTableOutputTypeDef:
+        """
+        Imports table data from an S3 bucket.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.import_table)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#import_table)
+        """
+
     def list_backups(
         self,
         *,
@@ -589,6 +624,16 @@ class DynamoDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#list_global_tables)
         """
 
+    def list_imports(
+        self, *, TableArn: str = ..., PageSize: int = ..., NextToken: str = ...
+    ) -> ListImportsOutputTypeDef:
+        """
+        Lists completed imports within the past 90 days.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html#DynamoDB.Client.list_imports)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client/#list_imports)
+        """
+
     def list_tables(
         self, *, ExclusiveStartTableName: str = ..., Limit: int = ...
     ) -> ListTablesOutputTypeDef:
