@@ -35,7 +35,10 @@ __all__ = (
     "ExportFormatType",
     "ExportStatusType",
     "GlobalTableStatusType",
+    "ImportStatusType",
     "IndexStatusType",
+    "InputCompressionTypeType",
+    "InputFormatType",
     "KeyTypeType",
     "ListBackupsPaginatorName",
     "ListTablesPaginatorName",
@@ -110,7 +113,10 @@ DestinationStatusType = Literal["ACTIVE", "DISABLED", "DISABLING", "ENABLE_FAILE
 ExportFormatType = Literal["DYNAMODB_JSON", "ION"]
 ExportStatusType = Literal["COMPLETED", "FAILED", "IN_PROGRESS"]
 GlobalTableStatusType = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
+ImportStatusType = Literal["CANCELLED", "CANCELLING", "COMPLETED", "FAILED", "IN_PROGRESS"]
 IndexStatusType = Literal["ACTIVE", "CREATING", "DELETING", "UPDATING"]
+InputCompressionTypeType = Literal["GZIP", "NONE", "ZSTD"]
+InputFormatType = Literal["CSV", "DYNAMODB_JSON", "ION"]
 KeyTypeType = Literal["HASH", "RANGE"]
 ListBackupsPaginatorName = Literal["list_backups"]
 ListTablesPaginatorName = Literal["list_tables"]
@@ -182,6 +188,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -327,6 +334,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -380,6 +388,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
